tokenizer\_tools.conllz package
===============================

Submodules
----------

tokenizer\_tools.conllz.entity\_vocabulary module
-------------------------------------------------

.. automodule:: tokenizer_tools.conllz.entity_vocabulary
   :members:
   :undoc-members:
   :show-inheritance:

tokenizer\_tools.conllz.iterator\_reader module
-----------------------------------------------

.. automodule:: tokenizer_tools.conllz.iterator_reader
   :members:
   :undoc-members:
   :show-inheritance:

tokenizer\_tools.conllz.reader module
-------------------------------------

.. automodule:: tokenizer_tools.conllz.reader
   :members:
   :undoc-members:
   :show-inheritance:

tokenizer\_tools.conllz.sentence module
---------------------------------------

.. automodule:: tokenizer_tools.conllz.sentence
   :members:
   :undoc-members:
   :show-inheritance:

tokenizer\_tools.conllz.tag\_collector module
---------------------------------------------

.. automodule:: tokenizer_tools.conllz.tag_collector
   :members:
   :undoc-members:
   :show-inheritance:

tokenizer\_tools.conllz.writer module
-------------------------------------

.. automodule:: tokenizer_tools.conllz.writer
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: tokenizer_tools.conllz
   :members:
   :undoc-members:
   :show-inheritance:
